firstname

# XMLRésuméLibrary: User Guide

fax | Element Reference | from

## Name

firstname — A person's given name

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `firstname` element specifies a person's first, or given, name. For example, in the name “Mr. Thomas B. Jones”, the first name is “Thomas”.

### Parents

`firstname` may be contained in these elements: `name`

## See Also

`middlenames`, `surname`.

## Examples

    <name>
      <firstname>Caroline</firstname>
      <surname>Francisca</surname>
    </name>

fax | Element Reference | from